@@ -39,6 +39,9 @@
 #include "ssh/seahorse-ssh-module.h"
 #endif
 
+#include "libegg/eggsmclient.h"
+#include "libegg/eggdesktopfile.h"
+
 #include <glib/gi18n.h>
 
 #include <sys/types.h>
@@ -56,17 +59,24 @@ static gboolean daemon_no_daemonize = FALSE;
 static gboolean daemon_running = FALSE;
 static gboolean daemon_quit = FALSE;
 
-static const gchar *daemon_icons[] = {
-    SEAHORSE_ICON_SHARING,
-    NULL
-};
-
 static const GOptionEntry options[] = {
     { "no-daemonize", 'd', 0, G_OPTION_ARG_NONE, &daemon_no_daemonize, 
         N_("Do not run seahorse-daemon as a daemon"), NULL },
     { NULL }
 };
 
+/**
+ * SECTION:seahorse-daemon
+ * @short_description: The seahorse-daemon. Offering services like DBus, HKP and
+ * Avahi
+ *
+ **/
+
+/**
+*
+* Daemonizing and some special handling for GPGME
+*
+**/
 static void
 daemonize ()
 {
@@ -115,6 +125,11 @@ daemonize ()
         exit (0);
 }
 
+/**
+*
+* The signal handler for termination
+*
+**/
 static void
 unix_signal (int signal)
 {
@@ -123,6 +138,30 @@ unix_signal (int signal)
         gtk_main_quit ();
 }
 
+/**
+* smclient: ignored
+* data: ignored
+*
+* The handler for the "quit" signal
+*
+**/
+static void
+smclient_quit (EggSMClient *smclient, gpointer data)
+{
+    daemon_quit = TRUE;
+    if (daemon_running)
+        gtk_main_quit ();    
+}
+
+/**
+* log_domain: will be added to the message. Can be NULL
+* log_level: the log level
+* message: the log message
+* user_data: passed to g_log_default_handler, nothing else
+*
+* Writes log messages
+*
+**/
 static void
 log_handler (const gchar *log_domain, GLogLevelFlags log_level, 
              const gchar *message, gpointer user_data)
@@ -165,6 +204,11 @@ log_handler (const gchar *log_domain, GLogLevelFlags log_level,
     g_log_default_handler (log_domain, log_level, message, user_data); 
 }
 
+/**
+*
+* Prepares the logging, sets the log handler to the function "log_handler"
+*
+**/
 static void
 prepare_logging ()
 {
@@ -180,6 +224,16 @@ prepare_logging ()
     g_log_set_handler ("Gnome", flags, log_handler, NULL);
 }
 
+
+/**
+ * main:
+ * @argc: default arguments
+ * @argv: default arguments
+ *
+ * Parses the options, daemonizes, starts HKP, DBus and Avahi
+ *
+ * Returns: 0 on success
+ */
 int main(int argc, char* argv[])
 {
     GOptionContext *octx = NULL;
@@ -191,6 +245,7 @@ int main(int argc, char* argv[])
     
     octx = g_option_context_new ("");
     g_option_context_add_main_entries (octx, options, GETTEXT_PACKAGE);
+    g_option_context_add_group (octx, egg_sm_client_get_option_group ());
 
     if (!gtk_init_with_args (&argc, &argv, _("Encryption Daemon (Seahorse)"), 
                              (GOptionEntry *)options, GETTEXT_PACKAGE, &error)) {
@@ -198,11 +253,13 @@ int main(int argc, char* argv[])
 	    g_error_free (error);
 	    exit (1);
     }
-	    
-
-    /* 
-     * All functions after this point have to print messages 
-     * nicely and not just called exit() 
+     	 
+	g_signal_connect (egg_sm_client_get (), "quit", G_CALLBACK (smclient_quit), NULL);
+    egg_set_desktop_file(AUTOSTARTDIR "/seahorse-daemon.desktop");
+    
+    /*
+     * All functions after this point have to print messages
+     * nicely and not just called exit()
      */
     daemonize ();
 
@@ -212,15 +269,14 @@ int main(int argc, char* argv[])
 
     /* Force gconf to reconnect after daemonizing */
     if (!daemon_no_daemonize)
-        seahorse_gconf_disconnect ();    
-        
+        seahorse_gconf_disconnect ();
+
     /* We log to the syslog */
     prepare_logging ();
 
     /* Insert Icons into Stock */
     seahorse_gtkstock_init ();
-    seahorse_gtkstock_add_icons (daemon_icons);
-    
+   
     /* Make the default SeahorseContext */
     seahorse_context_new (SEAHORSE_CONTEXT_APP | SEAHORSE_CONTEXT_DAEMON);
 
@@ -237,10 +293,6 @@ int main(int argc, char* argv[])
     /* Initialize the various daemon components */
     seahorse_dbus_server_init ();
 
-#ifdef WITH_SHARING
-    seahorse_sharing_init ();
-#endif
-
     /* Sometimes we've already gotten a quit signal */
     if(!daemon_quit) {
         daemon_running = TRUE;
@@ -248,13 +300,9 @@ int main(int argc, char* argv[])
         g_message ("left gtk_main\n");
     }
 
-    /* And now clean them all up */
-#ifdef WITH_SHARING
-    seahorse_sharing_cleanup ();
-#endif
-    
     seahorse_dbus_server_cleanup ();
 
+    g_option_context_free (octx);
     seahorse_context_destroy (SCTX_APP ());
     seahorse_cleanup_perform ();
 
